@@ -1,6 +1,8 @@
 var crsf_token = document.getElementsByName('csrfmiddlewaretoken')[0].value;
 axios.defaults.transformRequest = [function (data) {
-
+    if (!data) {
+        return data;
+    }
     if (data instanceof FormData) {
         return data;
     }
@@ -189,9 +191,12 @@ var app = new Vue({
             visible: false,
             title: '弹出层',
             params: [],
+            //elementui 要求表单是form才能校验
+            form: {},
             data: {},
-            rules: [],
-            action: ''
+            action: '',
+            rules: {},
+            loading: false
         },
         form: {
             show: true,
@@ -272,45 +277,56 @@ var app = new Vue({
         }
     },
     methods: {
+        layerValidate(url) {
+            let self = this;
+            this.$refs.layerForm.validate((valid) => {
+                if (valid) {
+                    self.layerDataSubmit(url);
+                }
+            });
+        },
         layerDataSubmit(url) {
             const self = this;
 
-            //校验
-            for (let key in self.params) {
-                let item = self.params[key];
-                if (item.require) {
-                    if (!item.value || item.value == '' || item.length == 0) {
-                        self.$message.error(`"${item.label}" Can't be empty.`)
-                        return;
-                    }
-                }
-            }
-
             //开始提交
             let formData = new FormData();
             //方法名
             formData.append('_action', self.layer.action);
-            let selected = [];
 
-            self.table.selection.forEach(item => selected.push(item._id));
+            //如果是选中全部的情况下，带搜索条件过去
+            if (self.search.all == 1) {
+                formData.append('_search', self.search.search);
+                //filter需要过滤数据
+                let filter = {};
+                for (let key in self.search.filters) {
+                    if (self.search.filters[key] !== '') {
+                        filter[key] = self.search.filters[key];
+                    }
+                }
+
+                formData.append('_filter', JSON.stringify(filter));
+            } else {
+                let selected = [];
+                self.table.selection.forEach(item => selected.push(item._id));
+                formData.append('_selected', selected.join(','));
+            }
+
 
-            formData.append('_selected', selected.join(','));
             formData.append('select_across', self.search.all);
             //获取选中的数据
 
             formData.append('csrfmiddlewaretoken', document.querySelector('[name="csrfmiddlewaretoken"]').value);
 
-            for (let key in self.layer.params) {
-                let item = self.layer.params[key];
-                if (item.type === "file") {
-                    formData.append(item.key, this.$refs[item.key][0].files[0]);
-                } else if (item.value) {
-                    formData.append(item.key, item.value);
+            //获取表单数据
+            for (let key in self.layer.form) {
+                let value = self.layer.form[key];
+                if (value) {
+                    formData.append(key, value);
                 }
             }
 
             axios.post(url, formData).then(res => {
-                if (res.data.status == 'success') {
+                if (res.data.status === 'success') {
                     self.layer.visible = false;
                     self.refreshData();
                 }
@@ -480,6 +496,92 @@ var app = new Vue({
                 window.location.href = url;
             }
         },
+        processLayer(action, layer) {
+            let self = this;
+            //处理异步配置的layer
+            if (layer.is_fun) {
+                self.layer.loading = true;
+                self.layer.visible = true;
+
+                  //开始提交
+            let formData = new FormData();
+            //方法名
+            formData.append('_action', action);
+
+            //如果是选中全部的情况下，带搜索条件过去
+            if (self.search.all == 1) {
+                formData.append('_search', self.search.search);
+                //filter需要过滤数据
+                let filter = {};
+                for (let key in self.search.filters) {
+                    if (self.search.filters[key] !== '') {
+                        filter[key] = self.search.filters[key];
+                    }
+                }
+
+                formData.append('_filter', JSON.stringify(filter));
+            } else {
+                let selected = [];
+                self.table.selection.forEach(item => selected.push(item._id));
+                formData.append('_selected', selected.join(','));
+            }
+
+
+            formData.append('select_across', self.search.all);
+            //获取选中的数据
+
+            formData.append('csrfmiddlewaretoken', document.querySelector('[name="csrfmiddlewaretoken"]').value);
+
+            //获取表单数据
+            for (let key in self.layer.form) {
+                let value = self.layer.form[key];
+                if (value) {
+                    formData.append(key, value);
+                }
+            }
+
+            axios.post(`${layer.url}`,formData).then(res => {
+                self.showLayer(action, res.data);
+            }).finally(() => self.layer.loading = false);
+
+            } else {
+                this.showLayer(action, layer);
+            }
+
+
+        },
+        showLayer(action, layer) {
+            let self = this;
+            self.layer.data = layer;
+            self.layer.title = layer.title;
+            self.layer.params = layer.params;
+            //生成规则
+            self.layer.rules = {};
+            let form = {};
+
+            for (let index in layer.params) {
+                let item = layer.params[index];
+
+                //组装成form
+                let key = item.key;
+                //form
+                form[key] = item.value;
+                if (item.require) {
+                    self.layer.rules[key] = [{
+                        required: true,
+                        message: item.label,
+                        trigger: 'blur'
+                    }]
+                }
+            }
+
+            self.layer.form = form;
+            self.layer.action = action;
+
+            self.$nextTick(() => {
+                self.layer.visible = true;
+            });
+        },
         customButtonClick: function (btn, key) {
             const self = this;
             if (window.SIMPLEAPI && window.SIMPLEAPI.toolbar) {
@@ -491,15 +593,7 @@ var app = new Vue({
 
             //处理layer
             if (btn.layer) {
-                self.layer.data = btn.layer;
-                self.layer.title = btn.layer.title;
-                self.layer.params = btn.layer.params;
-                self.layer.action = key;
-
-                self.$nextTick(() => {
-                    self.layer.visible = true;
-                });
-
+                this.processLayer(key, btn.layer);
                 return;
             }
 
@@ -597,16 +691,12 @@ var app = new Vue({
                 this.$refs.table.clearSelection();
                 this.table.selection = [];
                 this.toolbars.showAll = false;
-                //选择bug
                 this.toolbars.isActive = true;
             } else {
-                //选择bug
                 this.toolbars.isActive = false;
             }
             this.search.all = this.search.all == 0 ? 1 : 0
 
-            //改变导出按钮
-            console.log("aaa")
         },
         changeDate: function (dateList, field, type) {
             if (dateList) {
